@@ -25,13 +25,13 @@
 #'
 #' getCountryCode(longitude, latitude)
 #'
-#' @references \url{http://www.naturalearthdata.com/downloads/10m-cultural-vectors/}
+#' @references http://www.naturalearthdata.com/downloads/10m-cultural-vectors/
 #' @seealso SimpleCountries
 #' @seealso getSpatialData
 #'
 getCountryCode <- function(
-  longitude,
-  latitude,
+  longitude = NULL,
+  latitude = NULL,
   dataset = "SimpleCountriesEEZ",
   countryCodes = NULL,
   allData = FALSE,
@@ -40,6 +40,12 @@ getCountryCode <- function(
 
   # ----- Validate parameters --------------------------------------------------
 
+  MazamaCoreUtils::stopIfNull(longitude)
+  MazamaCoreUtils::stopIfNull(latitude)
+  MazamaCoreUtils::stopIfNull(dataset)
+  MazamaCoreUtils::stopIfNull(allData)
+  MazamaCoreUtils::stopIfNull(useBuffering)
+
   # Check existence of dataset
   if ( !exists(dataset) ) {
     stop("Missing dataset. Please loadSpatialData(\"", dataset, "\")",
