@@ -36,8 +36,8 @@
 #' @seealso getSpatialData
 #'
 getState <- function(
-  longitude,
-  latitude,
+  longitude = NULL,
+  latitude = NULL,
   dataset = "NaturalEarthAdm1",
   countryCodes = NULL,
   allData = FALSE,
@@ -46,6 +46,12 @@ getState <- function(
 
   # ----- Validate parameters --------------------------------------------------
 
+  MazamaCoreUtils::stopIfNull(longitude)
+  MazamaCoreUtils::stopIfNull(latitude)
+  MazamaCoreUtils::stopIfNull(dataset)
+  MazamaCoreUtils::stopIfNull(allData)
+  MazamaCoreUtils::stopIfNull(useBuffering)
+
   # Check existence of dataset
   if ( !exists(dataset) ) {
     stop("Missing dataset. Please loadSpatialData(\"",dataset,"\")",
