@@ -35,8 +35,8 @@
 #' @seealso getSpatialData
 #'
 getStateName <- function(
-  longitude,
-  latitude,
+  longitude = NULL,
+  latitude = NULL,
   dataset = "NaturalEarthAdm1",
   countryCodes = NULL,
   allData = FALSE,
@@ -45,6 +45,12 @@ getStateName <- function(
 
   # ----- Validate parameters --------------------------------------------------
 
+  MazamaCoreUtils::stopIfNull(longitude)
+  MazamaCoreUtils::stopIfNull(latitude)
+  MazamaCoreUtils::stopIfNull(dataset)
+  MazamaCoreUtils::stopIfNull(allData)
+  MazamaCoreUtils::stopIfNull(useBuffering)
+
   # Check existence of dataset
   if ( !exists(dataset) ) {
     stop("Missing dataset. Please loadSpatialData(\"",dataset,"\")",
