@@ -3,7 +3,7 @@ testthat::context("getCountryName()")
 
 testthat::test_that("handles errors correctly", {
   testthat::expect_error(getCountryName(),
-                         'argument "longitude" is missing, with no default')
+                         "argument 'longitude' must not be NULL.")
   testthat::expect_error(getCountryName(0,100))
 })
 
